# Replication

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_replication
        - start_replication
        - stop_replication
        - get_replications
        - get_replication_tasks
        - get_replication_task_log
        - get_replication_policy
        - create_replication_policy
        - update_replication_policy
        - delete_replication_policy
        - get_replication_policies
